@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2015-07-31'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2015-08-01'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use strict;
@@ -836,7 +836,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.18 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-07-31.
+This document describes version 0.19 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2015-08-01.
 
 =head1 SYNOPSIS
 
@@ -862,23 +862,23 @@ B<EARLY DEVELOPMENT.>
 
 Sample startup overhead benchmark vs Perinci::CmdLine::Lite:
 
-                                  Rate run 1 (lite) run --version (lite)   -c (lite) run 1 (inline) run --version (inline) -c (inline)   perl
- run 1 (lite)           13.502+-0.02/s           --               -60.2%      -81.8%         -88.2%                 -91.7%      -93.6% -97.4%
- run --version (lite)    33.93+-0.18/s  151.3+-1.4%                   --      -54.3%         -70.3%                 -79.0%      -83.9% -93.4%
- -c (lite)               74.33+-0.43/s  450.5+-3.3%          119.1+-1.7%          --         -34.9%                 -54.1%      -64.6% -85.4%
- run 1 (inline)         114.17+-0.51/s    745.6+-4%          236.5+-2.3%  53.6+-1.1%             --                 -29.4%      -45.7% -77.6%
- run --version (inline)   161.8+-1.1/s 1098.4+-8.3%          376.9+-4.1% 117.7+-1.9%     41.7+-1.1%                     --      -23.0% -68.3%
- -c (inline)              210.2+-1.9/s    1457+-15%          519.6+-6.6% 182.9+-3.1%     84.2+-1.9%             29.9+-1.5%          -- -58.8%
- perl                     510.8+-1.7/s    3683+-14%         1405.4+-9.5% 587.2+-4.6%    347.4+-2.5%            215.7+-2.4% 142.9+-2.4%     --
+                                    Rate  run 1 (lite) run --version (lite)     -c (lite) run 1 (inline) run --version (inline)  -c (inline)   perl
+ run 1 (lite)           9.7993+-0.0045/s            --               -57.2%        -76.7%         -84.0%                 -87.8%       -88.7% -94.4%
+ run --version (lite)     22.87+-0.028/s  133.39+-0.3%                   --        -45.7%         -62.8%                 -71.6%       -73.5% -86.9%
+ -c (lite)               42.116+-0.067/s 329.78+-0.71%         84.15+-0.37%            --         -31.4%                 -47.7%       -51.2% -75.9%
+ run 1 (inline)              61.4+-2.1/s      527+-22%          168.5+-9.4%    45.8+-5.1%             --                 -23.8%       -28.9% -64.9%
+ run --version (inline)      80.6+-3.2/s      723+-33%             252+-14%    91.4+-7.6%       31.3+-7%                     --        -6.7% -53.9%
+ -c (inline)              86.35+-0.049/s        781.2%         277.56+-0.5% 105.03+-0.35%     40.6+-4.9%              7.1+-4.3%           -- -50.6%
+ perl                     174.75+-0.68/s    1683.3+-7%          664.1+-3.1%   314.9+-1.8%     184.6+-10%            116.8+-8.7% 102.38+-0.8%     --
  
  Average times:
-   perl                  :     1.9577ms
-   -c (inline)           :     4.7574ms
-   run --version (inline):     6.1805ms
-   run 1 (inline)        :     8.7589ms
-   -c (lite)             :    13.4535ms
-   run --version (lite)  :    29.4724ms
-   run 1 (lite)          :    74.0631ms
+   perl                  :     5.7225ms
+   -c (inline)           :    11.5808ms
+   run --version (inline):    12.4069ms
+   run 1 (inline)        :    16.2866ms
+   -c (lite)             :    23.7439ms
+   run --version (lite)  :    43.7254ms
+   run 1 (lite)          :   102.0481ms
 
 =head1 FUNCTIONS
 
